bl_info = {
    "name": "House",
    "description": "Klasický domecek.",
    "author": "Jirí Chludil",
    "version": (1, 0, 0),
    "blender": (2, 77, 0),
    "location": "View3D > Add > Mesh > House",
    "warning": "",
    "wiki_url": "http://edux.fit.cvut.cz/courses/BI-PGA",
    "category": "Add Mesh"
}

import bpy
from mathutils import *
from math import *
from bpy.props import *


def add_house(size = (1. ,1. ,1.), roof = 1):
    verts = []
    edges = []
    faces = []
    size_x = size[0] / 2.0
    size_y = size[1] / 2.0
    size_z = size[2] / 2.0
    verts.append((-size_x, -size_y, -size_z))
    verts.append(( size_x, -size_y, -size_z))
    verts.append(( size_x, size_y, -size_z))
    verts.append((-size_x, size_y, -size_z))
    verts.append((-size_x, -size_y, size_z))
    verts.append(( size_x, -size_y, size_z))
    verts.append(( size_x, size_y, size_z))
    verts.append((-size_x, size_y, size_z))
    verts.append((-size_x, 0, size_z+roof))
    verts.append(( size_x, 0, size_z+roof))
    faces.append([0,1,2,3])
    faces.append([0,1,5,4])
    faces.append([1,2,6,5])
    faces.append([2,3,7,6])
    faces.append([3,0,4,7])
    faces.append([4,5,9,8])
    faces.append([6,7,8,9])
    faces.append([5,6,9])
    faces.append([4,7,8])
    return verts, edges, faces


def create_mesh_object(context, verts, edges, faces, name):
    # Vytvorení nové a prázdné mesh
    mesh = bpy.data.meshes.new(name)
    # konfigurace meshe prostrednictvím verts/edges/faces.
    mesh.from_pydata(verts, edges, faces)
    # Aktualizace mesh.
    mesh.update()

    from bpy_extras import object_utils
    return object_utils.object_data_add(context, mesh, operator=None)

class MyHouse(bpy.types.Operator):
    """House"""
    bl_idname = "object.house"
    bl_label = "House"
    bl_options = {'REGISTER', 'UNDO'}
    
    roof = bpy.props.FloatProperty(
        name = 'Roof', 
        description = 'House roof height',
        default = 1, min = 0.0, max=2.0, step=0.1
    )
    
    size = bpy.props.FloatVectorProperty(
        name = 'Size',
        description = 'Size',
        subtype = 'XYZ',
        default=(1.0, 1.0, 1.0),
    )
    
    def execute(self, context):
        # vytvorení geometrie
        verts, edges, faces = add_house(self.size,self.roof)
        # vytvorení objektu (meshe)
        obj = create_mesh_object(context, verts, edges, faces, "House")
        
        return {'FINISHED'}
    
def menu_func(self, context):
    self.layout.operator(MyHouse.bl_idname)
    # store keymaps addon_keymaps = []

def register():
    bpy.utils.register_module(__name__)
    bpy.types.INFO_MT_mesh_add.append(menu_func)
def unregister():
    bpy.utils.unregister_module(__name__)
    bpy.types.INFO_MT_mesh_add.remove(menu_func)

if __name__ == "__main__":
    register()